/************************************************************************/
/*  Command line parsing routines.					*/
/*									*/
/*	Douglas Neuhauser						*/
/*	Berkeley Seismological Laboratory				*/
/*	University of California, Berkeley				*/
/*	doug@seismo.berkeley.edu					*/
/*									*/
/************************************************************************/

/*
 * Copyright (c) 2012 The Regents of the University of California.
 * All Rights Reserved.
 * 
 * Permission to use, copy, modify, and distribute this software and its
 * documentation for educational, research and non-profit purposes,
 * without fee, and without a written agreement is hereby granted,
 * provided that the above copyright notice, this paragraph and the
 * following three paragraphs appear in all copies.
 * 
 * Permission to incorporate this software into commercial products may
 * be obtained from the Office of Technology Licensing, 2150 Shattuck
 * Avenue, Suite 510, Berkeley, CA  94704.
 * 
 * IN NO EVENT SHALL THE UNIVERSITY OF CALIFORNIA BE LIABLE TO ANY PARTY
 * FOR DIRECT, INDIRECT, SPECIAL, INCIDENTAL, OR CONSEQUENTIAL DAMAGES,
 * INCLUDING LOST PROFITS, ARISING OUT OF THE USE OF THIS SOFTWARE AND
 * ITS DOCUMENTATION, EVEN IF THE UNIVERSITY OF CALIFORNIA HAS BEEN
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 * THE UNIVERSITY OF CALIFORNIA SPECIFICALLY DISCLAIMS ANY WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.  THE SOFTWARE
 * PROVIDED HEREUNDER IS ON AN "AS IS" BASIS, AND THE UNIVERSITY OF
 * CALIFORNIA HAS NO OBLIGATIONS TO PROVIDE MAINTENANCE, SUPPORT,
 * UPDATES, ENHANCEMENTS, OR MODIFICATIONS.
 */

#ifndef lint
static const char sccsid[] = "$Id: parse_cmdline.c,v 1.3 2013/09/17 18:35:51 doug Exp $ ";
#endif

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <unistd.h>

#include "qlib2.h"

#include "externals.h"

#define	argc	(*pargc)
#define	argv	(*pargv)

double time_seconds(char *str);

/************************************************************************/
/*  parse_cmdline:							*/
/*	Parse command line.						*/
/************************************************************************/
int parse_cmdline 
   (int		*pargc,		/* ptr to argc.				*/
    char	***pargv)	/* ptr to argv.				*/
{

    /* Variables needed for getopt. */
    extern char	*optarg;
    extern int	optind, opterr;
    int		c;

    date_fmt = MONTH_FMT;
    delim = ',';
    cmdname = trim(*argv);
    time_precision = 6;

    /*	Parse command line options.					*/
    while ( (c = getopt(argc,argv,"hd:D:p:")) != -1)
	switch (c) {
	case '?':
	case 'h':   print_syntax(cmdname,syntax,info); exit(0); break;
	case 'd':   delim = optarg[0]; break;
	case 'p':   
	    time_precision = atoi(optarg);
	    if (time_precision < 0 || time_precision > 6) {
		fprintf (info, "Error: invalid precision for time -p %s\n", optarg);
		exit(1);
	    }
	    break;
	case 'D':
	    /* Date display format.   */
	    if (strcmp (optarg, "j") == 0) date_fmt = JULIAN_FMT;
	    else if (strcmp (optarg, "j,") == 0) date_fmt = JULIAN_FMT_1;
	    else if (strcmp (optarg, "m") == 0) date_fmt = MONTH_FMT;
	    else if (strcmp (optarg, "m,") == 0) date_fmt = MONTH_FMT_1;
	    else {
		fprintf (info, "Error: invalid format for date display: %s\n", optarg);
		exit(1);
	    }
	    break;
	}


    /*	Skip over all options and their arguments.			*/
    argv = &(argv[optind]);
    argc -= optind;

    /* The remaining arguments are optional input and output files.  */
    /* If there are none, then assume input from stdin and output to stdout. */

    if (argc-- > 0) input_file = *argv++;
    if (argc-- > 0) output_file = *argv++;
    if (input_file && (strcmp(input_file, "-") == 0)) input_file = NULL;
    if (output_file && (strcmp(output_file, "-") == 0)) output_file = NULL;
    if (output_file == NULL) info = stderr;

    return(0);
}
